@@ -42,10 +42,12 @@
 #include <torrent/hash_string.h>
 #include <torrent/tracker_list.h>
 #include <torrent/data/file_list.h>
+#include <torrent/peer/connection_list.h>
 
 #include "globals.h"
 
 namespace torrent {
+  class PeerList;
   class TrackerList;
 }
 
@@ -55,7 +57,9 @@ class Download {
 public:
   typedef torrent::Download             download_type;
   typedef torrent::FileList             file_list_type;
+  typedef torrent::PeerList             peer_list_type;
   typedef torrent::TrackerList          tracker_list_type;
+  typedef torrent::ConnectionList       connection_list_type;
   typedef download_type::ConnectionType connection_type;
 
   static const int variable_hashing_stopped = 0;
@@ -87,8 +91,16 @@ public:
   file_list_type*       file_list()                            { return m_download.file_list(); }
   const file_list_type* c_file_list() const                    { return m_download.file_list(); }
 
+  peer_list_type*       peer_list()                            { return m_download.peer_list(); }
+  const peer_list_type* c_peer_list() const                    { return m_download.peer_list(); }
+
   torrent::Object*    bencode()                                { return m_download.bencode(); }
-  tracker_list_type*  tracker_list()                           { return &m_trackerList; }
+
+  tracker_list_type*  tracker_list()                           { return m_download.tracker_list(); }
+  uint32_t            tracker_list_size() const                { return m_download.tracker_list()->size(); }
+
+  connection_list_type* connection_list()                      { return m_download.connection_list(); }
+  uint32_t              connection_list_size() const;
 
   const std::string&  message() const                          { return m_message; }
   void                set_message(const std::string& msg)      { m_message = msg; }
@@ -120,7 +132,6 @@ private:
 
   // Store the FileList instance so we can use slots etc on it.
   download_type       m_download;
-  tracker_list_type   m_trackerList;
 
   bool                m_hashFailed;
 
