@@ -195,10 +195,6 @@ DownloadFactory::receive_success() {
   if (!rtorrent->has_key_string("custom4")) rtorrent->insert_key("custom4", std::string());
   if (!rtorrent->has_key_string("custom5")) rtorrent->insert_key("custom5", std::string());
 
-  // Move to 'rtorrent'.
-  rpc::call_command("d.set_connection_leech", m_variables["connection_leech"], rpc::make_target(download));
-  rpc::call_command("d.set_connection_seed",  m_variables["connection_seed"], rpc::make_target(download));
-
   rpc::call_command("d.set_uploads_max",      rpc::call_command_void("get_max_uploads"), rpc::make_target(download));
   rpc::call_command("d.set_peers_min",        rpc::call_command_void("get_min_peers"), rpc::make_target(download));
   rpc::call_command("d.set_peers_max",        rpc::call_command_void("get_max_peers"), rpc::make_target(download));
@@ -261,6 +257,23 @@ DownloadFactory::receive_success() {
     if (m_manager->download_list()->find(infohash) == m_manager->download_list()->end())
       throw torrent::input_error("The newly created download was removed.");
 
+    // When a download scheduler is implemented, this is handled by
+    // the above insertion into download list.
+    if (m_session) {
+      // This torrent was queued for hashing or hashing when the
+      // session file was saved. Or it was in a started state.
+      if (rpc::call_command_value("d.get_hashing", rpc::make_target(download)) != Download::variable_hashing_stopped ||
+          rpc::call_command_value("d.get_state", rpc::make_target(download)) != 0)
+        m_manager->download_list()->resume(download);
+
+    } else {
+      // Use the state thingie here, move below.
+      if (m_start)
+        rpc::parse_command_single(rpc::make_target(download), "d.start=");
+
+      m_manager->download_store()->save(download);
+    }
+
   } catch (torrent::input_error& e) {
     std::string msg = "Command on torrent creation failed: " + std::string(e.what());
 
@@ -275,25 +288,6 @@ DownloadFactory::receive_success() {
       download->set_message(msg);
       //     m_manager->download_list()->erase(m_manager->download_list()->find(infohash.data()));
     }
-
-    return m_slotFinished();
-  }
-
-  // When a download scheduler is implemented, this is handled by the
-  // above insertion into download list.
-  if (m_session) {
-    // This torrent was queued for hashing or hashing when the session
-    // file was saved. Or it was in a started state.
-    if (rpc::call_command_value("d.get_hashing", rpc::make_target(download)) != Download::variable_hashing_stopped ||
-        rpc::call_command_value("d.get_state", rpc::make_target(download)) != 0)
-      m_manager->download_list()->resume(download);
-
-  } else {
-    // Use the state thingie here, move below.
-    if (m_start)
-      m_manager->download_list()->start_normal(download);
-
-    m_manager->download_store()->save(download);
   }
 
   m_slotFinished();
@@ -354,6 +348,9 @@ DownloadFactory::initialize_rtorrent(Download* download, torrent::Object* rtorre
                                                              download->download()->file_list()->size_chunks()));
 
   rtorrent->insert_preserve_copy("ignore_commands", (int64_t)0);
+
+  rtorrent->insert_preserve_type("connection_leech", m_variables["connection_leech"]);
+  rtorrent->insert_preserve_type("connection_seed", m_variables["connection_seed"]);
 }
 
 }
