@@ -54,6 +54,8 @@
 #include "control.h"
 #include "globals.h"
 #include "manager.h"
+#include "view.h"
+#include "view_manager.h"
 
 #include "dht_manager.h"
 #include "download.h"
@@ -75,7 +77,7 @@ struct download_list_call {
 
   void operator () (const DownloadList::slot_map::value_type& s) {
     try {
-      s.second(m_download);
+      rpc::parse_command_d_multiple_std(m_download, s.second);
     } catch (torrent::input_error& e) {
       control->core()->push_log((std::string("Download event action failed: ") + e.what()).c_str());
     }
@@ -164,6 +166,11 @@ DownloadList::insert(Download* download) {
     (*itr)->download()->signal_download_done(sigc::bind(sigc::mem_fun(*this, &DownloadList::received_finished), download));
     (*itr)->download()->signal_hash_done(sigc::bind(sigc::mem_fun(*this, &DownloadList::hash_done), download));
 
+    // This needs to be separated into two different calls to ensure
+    // the download remains in the view.
+    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::insert), download));
+    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::filter_download), download));
+
     std::for_each(slot_map_insert().begin(), slot_map_insert().end(), download_list_call(*itr));
 
   } catch (torrent::local_error& e) {
@@ -193,6 +200,7 @@ DownloadList::erase(iterator itr) {
   control->core()->download_store()->remove(*itr);
 
   std::for_each(slot_map_erase().begin(), slot_map_erase().end(), download_list_call(*itr));
+  std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::erase), *itr));
 
   torrent::download_remove(*(*itr)->download());
   delete *itr;
@@ -237,22 +245,6 @@ DownloadList::close(Download* download) {
   }
 }
 
-bool
-DownloadList::close_try(Download* download) {
-  try {
-    if (rpc::call_command_value("d.get_ignore_commands", rpc::make_target(download)) != 0)
-      return false;
-
-    rpc::call_command("d.set_state", (int64_t)0, rpc::make_target(download));
-    close_throw(download);
-    return true;
-
-  } catch (torrent::local_error& e) {
-    control->core()->push_log(e.what());
-    return false;
-  }
-}
-
 void
 DownloadList::close_directly(Download* download) {
   if (download->download()->is_active()) {
@@ -306,58 +298,6 @@ DownloadList::close_throw(Download* download) {
   std::for_each(slot_map_close().begin(), slot_map_close().end(), download_list_call(download));
 }
 
-void
-DownloadList::start_normal(Download* download) {
-  check_contains(download);
-
-  // Clear hash failed as we're doing a manual start and want to try
-  // hashing again.
-  download->set_hash_failed(false);
-  rpc::call_command("d.set_state", (int64_t)1, rpc::make_target(download));
-
-  resume(download);
-}
-
-bool
-DownloadList::start_try(Download* download) {
-  check_contains(download);
-
-  // Also don't start if the state is one of those that indicate we
-  // were manually stopped?
-
-  if (download->is_hash_failed() || rpc::call_command_value("d.get_ignore_commands", rpc::make_target(download)) != 0)
-    return false;
-
-  // Don't clear the hash failed as this function is used by scripts,
-  // etc.
-  rpc::call_command("d.set_state", (int64_t)1, rpc::make_target(download));
-
-  resume(download);
-  return true;
-}
-
-void
-DownloadList::stop_normal(Download* download) {
-  check_contains(download);
-
-  rpc::call_command("d.set_state", (int64_t)0, rpc::make_target(download));
-
-  pause(download);
-}
-
-bool
-DownloadList::stop_try(Download* download) {
-  check_contains(download);
-
-  if (rpc::call_command_value("d.get_ignore_commands", rpc::make_target(download)) != 0)
-    return false;
-
-  rpc::call_command("d.set_state", (int64_t)0, rpc::make_target(download));
-
-  pause(download);
-  return true;
-}
-
 void
 DownloadList::resume(Download* download, int flags) {
   check_contains(download);
@@ -367,6 +307,8 @@ DownloadList::resume(Download* download, int flags) {
     if (download->download()->is_active())
       return;
 
+    rpc::parse_command_single(rpc::make_target(download), "view.set_visible=active");
+
     // We need to make sure the flags aren't reset if someone decideds
     // to call resume() while it is hashing, etc.
     if (download->resume_flags() == ~uint32_t())
@@ -434,6 +376,8 @@ DownloadList::pause(Download* download, int flags) {
 
     download->set_resume_flags(~uint32_t());
 
+    rpc::parse_command_single(rpc::make_target(download), "view.set_not_visible=active");
+
     // Always clear hashing on pause. When a hashing request is added,
     // it should have cleared the hash resume data.
     if (rpc::call_command_value("d.get_hashing", rpc::make_target(download)) != Download::variable_hashing_stopped) {
@@ -454,6 +398,10 @@ DownloadList::pause(Download* download, int flags) {
     rpc::call_command("d.set_state_changed", cachedTime.seconds(), rpc::make_target(download));
     rpc::call_command("d.set_state_counter", rpc::call_command_value("d.get_state_counter", rpc::make_target(download)), rpc::make_target(download));
 
+    // If initial seeding is complete, don't try it again when restarting.
+    if (download->is_done())
+      rpc::call_command("d.set_connection_seed", rpc::call_command_void("d.get_connection_current", rpc::make_target(download)), rpc::make_target(download));
+
     // Save the state after all the slots, etc have been called so we
     // include the modifications they may make.
     //control->core()->download_store()->save(download);
