@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,14 +37,8 @@
 #ifndef RTORRENT_DISPLAY_TRACKER_LIST_H
 #define RTORRENT_DISPLAY_TRACKER_LIST_H
 
-#include <list>
-
 #include "window.h"
 
-namespace torrent {
-  class Tracker;
-}
-
 namespace core {
   class Download;
 }
