@@ -180,50 +180,49 @@ main(int argc, char** argv) {
        "view_add = default\n"
 
        "view_add = name\n"
-       "view_sort_new = name,name\n"
-       "view_sort_current = name,name\n"
+       "view_sort_new     = name,less=d.get_name=\n"
+       "view_sort_current = name,less=d.get_name=\n"
+
+       "view_add = active\n"
+       "view_filter = active,false=\n"
 
        "view_add = started\n"
-       "view_filter = started,started\n"
-       "view_filter_on = started,start,stop\n"
-       "view_sort_new = started,name\n"
-       "view_sort_current = started,name\n"
+       "view_filter = started,false=\n"
+       "view.event_added = started,scheduler.simple.added=\n"
+       "view.event_removed = started,scheduler.simple.removed=\n"
 
        "view_add = stopped\n"
-       "view_filter = stopped,stopped\n"
-       "view_filter_on = stopped,start,stop\n"
-       "view_sort_new = stopped,name\n"
-       "view_sort_current = stopped,name\n"
+       "view_filter = stopped,false=\n"
 
        "view_add = complete\n"
-       "view_filter = complete,complete\n"
+       "view_filter = complete,d.get_complete=\n"
        "view_filter_on = complete,hash_done,finished\n"
-       "view_sort_new = complete,state_changed\n"
-       "view_sort_current = complete,state_changed_reverse\n"
+       "view_sort_new     = complete,less=d.get_state_changed=\n"
+       "view_sort_current = complete,less=d.get_state_changed=\n"
 
        "view_add = incomplete\n"
-       "view_filter = incomplete,incomplete\n"
+       "view_filter = incomplete,not=$d.get_complete=\n"
        "view_filter_on = incomplete,hash_done,finished\n"
-       "view_sort_new = incomplete,state_changed\n"
-       "view_sort_current = incomplete,state_changed_reverse\n"
+       "view_sort_new     = incomplete,less=d.get_state_changed=\n"
+       "view_sort_current = incomplete,less=d.get_state_changed=\n"
 
        // The hashing view does not include stopped torrents.
        "view_add = hashing\n"
-       "view_filter = hashing,hashing\n"
+       "view_filter = hashing,d.get_hashing=\n"
        "view_filter_on = hashing,hash_queued,hash_removed,hash_done\n"
-       "view_sort_new = hashing,state_changed\n"
-       "view_sort_current = hashing,state_changed\n"
+//        "view_sort_new     = hashing,less=d.get_state_changed=\n"
+//        "view_sort_current = hashing,less=d.get_state_changed=\n"
 
        "view_add = seeding\n"
-       "view_filter = seeding,started,complete\n"
+       "view_filter = seeding,\"and=d.get_state=,d.get_complete=\"\n"
        "view_filter_on = seeding,start,stop\n"
-       "view_sort_new = seeding,state_changed\n"
-       "view_sort_current = seeding,state_changed_reverse\n"
+       "view_sort_new     = seeding,less=d.get_state_changed=\n"
+       "view_sort_current = seeding,less=d.get_state_changed=\n"
 
        // Changing these will bork the (non-existant) scheduler.
        "view_add = scheduler\n"
-       "view_sort_new = scheduler,state_changed\n" // add started?
-       "view_sort_current = scheduler,state_changed\n"
+//        "view_sort_new     = scheduler,less=d.get_state_changed=\n"
+//        "view_sort_current = scheduler,less=d.get_state_changed=\n"
 
        //    "schedule = scheduler,10,10,download_scheduler=\n"
 
