@@ -98,7 +98,7 @@ DownloadList::activate(display::Frame* frame, bool focus) {
   m_frame = frame;
 
   control->input()->push_back(&m_bindings);
-  control->core()->download_list()->slot_map_erase()["0_download_list"] = sigc::mem_fun(this, &DownloadList::receive_download_erased);
+  control->core()->download_list()->slot_map_erase()["0_download_list"] = "ui.unfocus_download=";
 
   activate_display(DISPLAY_DOWNLOAD_LIST);
 }
@@ -121,6 +121,18 @@ DownloadList::current_view() {
   return dynamic_cast<ElementDownloadList*>(m_uiArray[DISPLAY_DOWNLOAD_LIST])->view();
 }
 
+// This should also do focus_next() or something.
+void
+DownloadList::unfocus_download(core::Download* d) {
+  if (current_view()->focus() >= current_view()->end_visible() || *current_view()->focus() != d)
+    return;
+
+  if (m_state == DISPLAY_DOWNLOAD)
+    activate_display(DISPLAY_DOWNLOAD_LIST);
+
+  current_view()->next_focus();
+}
+
 void
 DownloadList::activate_display(Display displayType) {
   if (!is_active())
@@ -316,14 +328,6 @@ DownloadList::receive_exit_input(Input type) {
   delete input;
 }
 
-void
-DownloadList::receive_download_erased(core::Download* d) {
-  if (m_state != DISPLAY_DOWNLOAD || current_view()->focus() == current_view()->end_visible() || *current_view()->focus() != d)
-    return;
-
-  activate_display(DISPLAY_DOWNLOAD_LIST);
-}
-
 void
 DownloadList::setup_keys() {
   m_bindings['\x7f']        = sigc::bind(sigc::mem_fun(*this, &DownloadList::receive_view_input), INPUT_LOAD_DEFAULT);
