@@ -104,6 +104,8 @@ public:
 
   void                slot_open_uri(SlotOpenUri s) { m_slotOpenUri = s; }
 
+  void                unfocus_download(core::Download* d);
+
 private:
   DownloadList(const DownloadList&);
   void operator = (const DownloadList&);
@@ -111,8 +113,6 @@ private:
   void                receive_view_input(Input type);
   void                receive_exit_input(Input type);
 
-  void                receive_download_erased(core::Download* d);
-
   void                setup_keys();
   void                setup_input();
 
